# -*- coding: utf-8 -*-

"""Jinja2 extensions that introduce `os.path` functions as template filters."""

from __future__ import absolute_import

from .extensions import *

__author__ = "Moritz E. Beber"
__email__ = "morbeb@biosustain.dtu.dk"
__version__ = "0.1.0"
